Crate microformats_types

Crate microformats_types 

Core types for Microformats2 parsing.

This crate provides the fundamental data structures for representing Microformats2 parsed documents, items, properties, and values.

Features

  • metaformats - Enable metaformats backcompat support for Open Graph and Twitter Cards
  • debug_flow - Enable source tracking for debugging parsed values
  • per_element_lang - Enable per-element language tracking for TextValue and UrlValue

Re-exports

pub use class::Class;
pub use class::KnownClass;
pub use document::Document;
pub use error::Error;
pub use item::Item;
pub use item::Items;
pub use item::ValueKind;
pub use property_value::Fragment;
pub use property_value::Image;
pub use property_value::NodeList;
pub use property_value::Properties;
pub use property_value::PropertyValue;
pub use property_value::PropertyWithMetadata;
pub use relation::Relation;
pub use relation::Relations;
pub use traits::FindItemById;
pub use traits::FindItemByProperty;
pub use traits::FindItemByUrl;
pub use traits::LanguageFilter;

Modules

class
Microformat class types.
document
Parsed document container.
error
Error types for parsing.
item
Microformat item types.
property_value
Property value types.
relation
Link relation types. Link relation types for Microformats2 documents.
temporal
Temporal value types.
traits
Utility traits for item lookup.

Structs

TextValue
A text value with optional language information.
Url
A parsed URL record.
UrlValue
A URL value with optional language information.

Type Aliases

Microformat
Alias for Item, representing a parsed microformat.